@@ -36,7 +36,7 @@ use libp2p_plaintext::PlainText2Config;
 use libp2p_relay::{Relay, RelayConfig};
 use libp2p_swarm::protocols_handler::KeepAlive;
 use libp2p_swarm::{
-    DialError, DummyBehaviour, NetworkBehaviour, NetworkBehaviourAction,
+    dial_opts::DialOpts, DialError, DummyBehaviour, NetworkBehaviour, NetworkBehaviourAction,
     NetworkBehaviourEventProcess, PollParameters, Swarm, SwarmEvent,
 };
 use std::task::{Context, Poll};
@@ -146,7 +146,7 @@ fn src_connect_to_dst_listening_via_relay() {
             }
         };
 
-        src_swarm.dial_addr(dst_addr_via_relay).unwrap();
+        src_swarm.dial(dst_addr_via_relay).unwrap();
         let src = async move {
             // Source Node dialing Relay to connect to Destination Node.
             match src_swarm.select_next_some().await {
@@ -221,7 +221,7 @@ fn src_connect_to_dst_not_listening_via_active_relay() {
     dst_swarm.listen_on(Protocol::P2pCircuit.into()).unwrap();
     spawn_swarm_on_pool(&pool, dst_swarm);
 
-    src_swarm.dial_addr(dst_addr_via_relay).unwrap();
+    src_swarm.dial(dst_addr_via_relay).unwrap();
     pool.run_until(async move {
         // Source Node dialing Relay to connect to Destination Node.
         match src_swarm.select_next_some().await {
@@ -307,7 +307,7 @@ fn src_connect_to_dst_via_established_connection_to_relay() {
     spawn_swarm_on_pool(&pool, dst_swarm);
 
     pool.run_until(async move {
-        src_swarm.dial_addr(relay_addr).unwrap();
+        src_swarm.dial(relay_addr).unwrap();
 
         // Source Node establishing connection to Relay.
         loop {
@@ -321,7 +321,7 @@ fn src_connect_to_dst_via_established_connection_to_relay() {
             }
         }
 
-        src_swarm.dial_addr(dst_addr_via_relay).unwrap();
+        src_swarm.dial(dst_addr_via_relay).unwrap();
 
         // Source Node establishing connection to destination node via Relay.
         loop {
@@ -375,7 +375,7 @@ fn src_try_connect_to_offline_dst() {
     relay_swarm.listen_on(relay_addr.clone()).unwrap();
     spawn_swarm_on_pool(&pool, relay_swarm);
 
-    src_swarm.dial_addr(dst_addr_via_relay.clone()).unwrap();
+    src_swarm.dial(dst_addr_via_relay.clone()).unwrap();
     pool.run_until(async move {
         // Source Node dialing Relay to connect to Destination Node.
         match src_swarm.select_next_some().await {
@@ -433,7 +433,7 @@ fn src_try_connect_to_unsupported_dst() {
     dst_swarm.listen_on(dst_addr.clone()).unwrap();
     spawn_swarm_on_pool(&pool, dst_swarm);
 
-    src_swarm.dial_addr(dst_addr_via_relay.clone()).unwrap();
+    src_swarm.dial(dst_addr_via_relay.clone()).unwrap();
     pool.run_until(async move {
         // Source Node dialing Relay to connect to Destination Node.
         match src_swarm.select_next_some().await {
@@ -484,7 +484,7 @@ fn src_try_connect_to_offline_dst_via_offline_relay() {
         .with(dst_addr.into_iter().next().unwrap())
         .with(Protocol::P2p(dst_peer_id.clone().into()));
 
-    src_swarm.dial_addr(dst_addr_via_relay.clone()).unwrap();
+    src_swarm.dial(dst_addr_via_relay.clone()).unwrap();
     pool.run_until(async move {
         // Source Node dialing Relay to connect to Destination Node.
         match src_swarm.select_next_some().await {
@@ -761,7 +761,7 @@ fn inactive_connection_timeout() {
     spawn_swarm_on_pool(&pool, dst_swarm);
 
     pool.run_until(async move {
-        src_swarm.dial_addr(relay_addr).unwrap();
+        src_swarm.dial(relay_addr).unwrap();
         // Source Node dialing Relay.
         loop {
             match src_swarm.select_next_some().await {
@@ -773,7 +773,7 @@ fn inactive_connection_timeout() {
             }
         }
 
-        src_swarm.dial_addr(dst_addr_via_relay).unwrap();
+        src_swarm.dial(dst_addr_via_relay).unwrap();
 
         // Source Node establishing connection to destination node via Relay.
         match src_swarm.select_next_some().await {
@@ -841,8 +841,8 @@ fn concurrent_connection_same_relay_same_dst() {
     spawn_swarm_on_pool(&pool, dst_swarm);
 
     pool.run_until(async move {
-        src_swarm.dial_addr(dst_addr_via_relay.clone()).unwrap();
-        src_swarm.dial_addr(dst_addr_via_relay).unwrap();
+        src_swarm.dial(dst_addr_via_relay.clone()).unwrap();
+        src_swarm.dial(dst_addr_via_relay).unwrap();
 
         // Source Node establishing two connections to destination node via Relay.
         let mut num_established = 0;
@@ -987,8 +987,8 @@ fn yield_incoming_connection_through_correct_listener() {
         }
     });
 
-    src_1_swarm.dial_addr(dst_addr_via_relay_1.clone()).unwrap();
-    src_2_swarm.dial_addr(dst_addr_via_relay_2.clone()).unwrap();
+    src_1_swarm.dial(dst_addr_via_relay_1.clone()).unwrap();
+    src_2_swarm.dial(dst_addr_via_relay_2.clone()).unwrap();
     spawn_swarm_on_pool(&pool, src_1_swarm);
     spawn_swarm_on_pool(&pool, src_2_swarm);
 
@@ -1047,7 +1047,7 @@ fn yield_incoming_connection_through_correct_listener() {
 
     // Expect destination node to reject incoming connection from unknown relay given that
     // destination node is not listening for such connections.
-    src_3_swarm.dial_addr(dst_addr_via_relay_3.clone()).unwrap();
+    src_3_swarm.dial(dst_addr_via_relay_3.clone()).unwrap();
     pool.run_until(async {
         loop {
             futures::select! {
@@ -1117,7 +1117,7 @@ fn yield_incoming_connection_through_correct_listener() {
 
     // Expect destination node to accept incoming connection from "unknown" relay, i.e. the
     // connection from source node 3 via relay 3.
-    src_3_swarm.dial_addr(dst_addr_via_relay_3.clone()).unwrap();
+    src_3_swarm.dial(dst_addr_via_relay_3.clone()).unwrap();
     pool.run_until(async move {
         loop {
             match src_3_swarm.select_next_some().await {
